@@ -39,6 +39,7 @@ class Client(object):
 
         self._http_client = HttpClient(self, base_url)
 
+        self.action_items = ActionItemResource(self._http_client)
         self.article_highlights = ArticleHighlightsResource(self._http_client)
         self.article_companies = ArticleCompanyResource(self._http_client)
         self.article_people = ArticlePersonResource(self._http_client)
@@ -51,8 +52,11 @@ class Client(object):
         self.company_industries = CompanyIndustryResource(self._http_client)
         self.company_key_terms = CompanyKeyTermResource(self._http_client)
         self.company_profile = CompanyProfileResource(self._http_client)
+        self.conference = ConferenceResource(self._http_client)
+        self.conference_speaker = ConferenceSpeakerResource(self._http_client)
         self.domains = DomainResource(self._http_client)
         self.industries = IndustryResource(self._http_client)
+        self.feed = FeedResource(self._http_client)
         self.key_terms = KeyTermResource(self._http_client)
         self.organizations = OrganizationResource(self._http_client)
         self.people = PersonResource(self._http_client)
@@ -71,6 +75,7 @@ class Client(object):
         self.user_contacts = UserContactResource(self._http_client)
         self.user_digest_subscriptions = UserDigestSubscriptionResource(self._http_client)
         self.user_key_terms = UserKeyTermResource(self._http_client)
+        self.user_person = UserPersonResource(self._http_client)
         self.user_sources = UserSourceResource(self._http_client)
         self.users = UserResource(self._http_client)
         self.videos = VideoResource(self._http_client)
