@@ -2,6 +2,7 @@
 hudai.resources
 """
 
+from .action_item import ActionItemResource
 from .article import ArticleResource
 from .article_company import ArticleCompanyResource
 from .article_person import ArticlePersonResource
@@ -14,7 +15,10 @@ from .company_event import CompanyEventResource
 from .company_industry import CompanyIndustryResource
 from .company_key_term import CompanyKeyTermResource
 from .company_profile import CompanyProfileResource
+from .conference import ConferenceResource
+from .conference_speaker import ConferenceSpeakerResource
 from .domain import DomainResource
+from .feed import FeedResource
 from .industry import IndustryResource
 from .key_term import KeyTermResource
 from .organization import OrganizationResource
@@ -35,6 +39,7 @@ from .user_company_group import UserCompanyGroupResource
 from .user_contact import UserContactResource
 from .user_digest_subscription import UserDigestSubscriptionResource
 from .user_key_term import UserKeyTermResource
+from .user_person import UserPersonResource
 from .user_source import UserSourceResource
 from .video import VideoResource
 from .video_company import VideoCompanyResource
