@@ -44,4 +44,4 @@ class CompanyResource(Resource):
         )
 
     def suggest(self, query_string):
-        return self.http_get('/suggest', query_params={'query': query_string})
+        return self.http_get('/search/suggest', query_params={'query': query_string})
